from distutils.core import setup

setup(
	name ='Abbas',
	version ='1.0.0',
	py_modules=['Abbas'],
	author='abbas',
	author_email='abbasalizaidi1990@gmail.com',
	description='A simple printer of lists'
     )

